@@ -22,29 +22,27 @@
 
 #include <QAbstractListModel>
 
-#include <utils/override.h>
-#include <utils/nullptr.h>
 #include <utils/d_ptr.h>
 
 /**
  * BlacklistedApplicationsModel
  */
-class BlacklistedApplicationsModel: public QAbstractListModel {
+class BlacklistedApplicationsModel : public QAbstractListModel {
     Q_OBJECT
 
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
 
 public:
-    BlacklistedApplicationsModel(QObject * parent = nullptr);
+    BlacklistedApplicationsModel(QObject *parent = Q_NULLPTR);
 
     enum Roles {
         ApplicationIdRole = Qt::UserRole + 1,
         BlockedApplicationRole
     };
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const _override;
-    QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const _override;
-    int rowCount(const QModelIndex & parent = QModelIndex()) const _override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void changed();
@@ -65,4 +63,3 @@ private:
 };
 
 #endif // BLACKLISTED_APPLICATIONS_MODEL_H
-
